body
{
  margin: 0px 0px 0px 0px;
  padding: 0px 0px 0px 0px;
  font-family: verdana, arial, helvetica, sans-serif;
  color: black;
  background-color: #ffffff;
}

a
{
  text-decoration: none;
  color:  #cc9966;
  outline: none;
}

a:visited
{
  color:  #999;
}

a:active
{
  color:  #ccc;
}

a:hover
{
  color: #666;
  text-decoration: none;
}

strong, b
{
  font-weight: bold;
}

p
{
  color: #333;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 12px;
  line-height: 14px;
  margin-top: 2px;
  margin-bottom: 10px; 
}

h2
{
  color: #A80806;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 12px;
  line-height: 18px;
  font-weight: bold;
  margin-top: 0;
  margin-bottom: 0;
}

h3
{
  color: #336600;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  line-height: 14px;
  margin-top: 0;
  margin-bottom: 0;
}	

h4
{
  color: #333;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  line-height: 18px;
  font-weight: bold;
  margin-top: 0;
  margin-bottom: 0;
}

h4.error { color:red; }

.h4
{ 
  color: #333;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  line-height: 18px;
  font-weight: normal;
  margin-top: 0;
  margin-bottom: 0;
}

h5
{
  color: #666633;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  line-height: 14px;
  margin-top: 0;
  margin-bottom: 0;
}	

h6
{
  color: #A80806;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  text-align: right;
  line-height: 24px;
  font-weight: bold;
  margin-top: 0;
  margin-bottom: 0;
}

h7
{
  color: #333;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
  line-height: 10px;
  font-weight: bold;
  margin-top: 0;
  margin-bottom: 0;
}

#top
{
  margin: 10px 10px 0px 10px;
  padding: 2px;
  border: 1px solid #A80806;
  background: #000000;
  height: 100px; /* ie5win fudge begins */
  voice-family: "\"}\"";
  voice-family:inherit;
  height: 78px;
  }
  html>body #top {
    height: 78px; /* ie5win fudge ends */
}

#hometop
{
  margin: 10px 10px 0px 10px;
  padding: 2px;
  border: 1px solid #A80806;
  background: #000000;
  height: 100px; /* ie5win fudge begins */
  voice-family: "\"}\"";
  voice-family:inherit;
  height: 78px;
  }
  html>body #hometop {
    height: 78px; /* ie5win fudge ends */
}

#crumb
{
  margin: 6px 10px 0px 10px;
  padding: 0px 4px 4px 4px;
  background: #f3f5e5;
  height: 100px; /* ie5win fudge begins */
  voice-family: "\"}\"";
  voice-family:inherit;
  height: 20px;
  }
  html>body #top {
    height: 20px; /* ie5win fudge ends */
}

#toptwo
{
  margin: 10px 10px 0px 10px;
  padding: 2px;
  border: 1px solid #A80806;
  background: #000000;
  height: 100px; /* ie5win fudge begins */
  voice-family: "\"}\"";
  voice-family:inherit;
  height: 24px;
  }
  html>body #top {
    height: 24px; /* ie5win fudge ends */
}
	
.levelone
{
  margin: 10px 10px 0px 10px;
  padding: 4px;
  border: 1px solid #A80806;
  background: #f3f5e5;
}

#bottom
{
  margin: 10px 10px 0px 10px;
  padding: 4px;
  border: 1px solid #A80806;
  background: #000000;
  height: 100px; /* ie5win fudge begins */
  voice-family: "\"}\"";
  voice-family:inherit;
  height: 24px;
  }
  html>body #bottom {
    height: 24px; /* ie5win fudge ends */
}
	
.left
{
  margin-top: 5px;
  margin-left: 10px;
  margin-right: 10px;
  padding: 10px;
  border: 1px solid #e6bab9;
  background: #f3f5e5;
}

.left_invisible { color: #f3f5e5; }

.middle
{
  margin-top: 5px;
  margin-right: 10px;
  padding: 10px;
  border: 1px solid #e6bab9;
  background: #d8ddb3;
}

.middle_invisible { color: #d8ddb3; }

.right
{
  margin-top: 5px;
  margin-right: 10px;
  padding: 10px;
  border: 1px solid #999;
  background: #ccc;
}

.page
{
  margin-left: 10x;
  margin-right: 10x;
  padding: 10px;
}

pre
{
  color: #555;
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 12px;
  line-height: 22px;
  margin-top: 20px;
  margin-bottom: 10px; 
}

.schema-list
{
  margin-left: 10x;
  margin-right: 10x;
  padding: 10px;
}

.text
{
  font-family: verdana, arial, helvetica, sans-serif;
  font-size: 10px;
}